@@ -1,4 +1,4 @@
-/* $Id: sysdeps.c,v 1.7 1999/07/30 21:03:19 martin Exp $ */
+/* $Id: sysdeps.c,v 1.13 2004/06/09 18:52:20 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,11 +22,13 @@
 */
 
 #include <locale.h>
+#include <libintl.h>
+#include <stdio.h>
 
 #include <glibtop.h>
 #include <glibtop/open.h>
 #include <glibtop/close.h>
-#include <glibtop/xmalloc.h>
+#include <glibtop/sysdeps.h>
 
 #include <glibtop/parameter.h>
 
@@ -44,9 +46,9 @@ main (int argc, char *argv [])
 	count = PROFILE_COUNT;
 
 	setlocale (LC_ALL, "");
-	bindtextdomain (PACKAGE, GTOPLOCALEDIR);
-	textdomain (PACKAGE);
-	
+	bindtextdomain (GETTEXT_PACKAGE, GTOPLOCALEDIR);
+	textdomain (GETTEXT_PACKAGE);
+
 	glibtop_init_r (&glibtop_global_server, 0, GLIBTOP_INIT_NO_OPEN);
 
 	glibtop_get_parameter (GLIBTOP_PARAM_METHOD, &method, sizeof (method));
@@ -69,13 +71,10 @@ main (int argc, char *argv [])
 
 	glibtop_get_sysdeps (&sysdeps);
 
-#define FEATURE_CHECK(f) ((sysdeps.features & (1L << GLIBTOP_SYSDEPS_##f##)) ? 1 : 0)
+#define FEATURE_CHECK(f) ((sysdeps.features & (1L << GLIBTOP_SYSDEPS_##f)) ? 1 : 0)
 
 	printf ("Sysdeps (0x%08lx):\n\n"
 		"\tfeatures:\t\t0x%08lx\n\n"
-#if LIBGTOP_VERSION_CODE > 1001000
-		"\tpointer_size:\t\t0x%08lx\n\n"
-#endif
 		"\tcpu:\t\t%d\t0x%08lx\n"
 		"\tmem:\t\t%d\t0x%08lx\n"
 		"\tswap:\t\t%d\t0x%08lx\n\n"
@@ -100,9 +99,6 @@ main (int argc, char *argv [])
 		"\tppp:\t\t%d\t0x%08lx\n\n",
 		(unsigned long) sysdeps.flags,
 		(unsigned long) sysdeps.features,
-#if LIBGTOP_VERSION_CODE > 1001000
-		(unsigned long) sysdeps.pointer_size,
-#endif
 		FEATURE_CHECK(CPU),
 		(unsigned long) sysdeps.cpu,
 		FEATURE_CHECK(MEM),
